@@ -1,9 +1,9 @@
 #ifndef lint
 static const char rcsid[] =
-    "@(#) $Id: cupdate.c 39 2018-03-20 00:53:44Z leres $ (LBL)";
+    "@(#) $Id: cupdate.c 41 2020-03-25 19:34:30Z leres $ (LBL)";
 #endif
 /*
- * Copyright (c) 2005, 2006, 2008, 2009, 2010, 2013, 2016, 2018
+ * Copyright (c) 2005, 2006, 2008, 2009, 2010, 2013, 2016, 2018, 2020
  *	Craig Leres
  */
 
@@ -40,8 +40,9 @@ void __attribute__((noreturn)) usage(void);
 int
 main(int argc, char **argv)
 {
-	register int op, n;
-	register char *cp, *cmd, *out, ch;
+	int op, n;
+	long lv;
+	char *cp, *ep, *cmd, *out, ch;
 	fd_set rfds;
 	struct timeval tv;
 	WINDOW *win;
@@ -66,12 +67,10 @@ main(int argc, char **argv)
 			break;
 
 		case 'w':
-			waitsecs = atoi(optarg);
-			if (waitsecs <= 0) {
-				fprintf(stderr, "%s: waitsecs must be > 0\n",
-				    prog);
-				exit(1);
-			}
+			lv = strtol(optarg, &ep, 10);
+			if (*ep != '\0' || lv <= 0)
+				usage();
+			waitsecs = lv;
 			break;
 
 		default:
@@ -145,10 +144,10 @@ main(int argc, char **argv)
 }
 
 char *
-buildcommand(register int ac, register char **av)
+buildcommand(int ac, char **av)
 {
-	register int n, len;
-	register char *cp, *cmd;
+	int n, len;
+	char *cp, *cmd;
 	static const char redirect[] = " 2>&1";
 
 	/* Room for optional for "(" and ")" */
@@ -192,11 +191,11 @@ finish()
 }
 
 char *
-runcommand(register char *cmd)
+runcommand(char *cmd)
 {
-	register FILE *p;
-	register char *cp;
-	register int n, cc, len;
+	FILE *p;
+	char *cp;
+	int n, cc, len;
 	static int size = 0;
 	static char *out = NULL;
 
